@@ -9,7 +9,7 @@ class Xfer:
 
 	def __init__(self, core: Core, parent):
 		self._core = core
-		self._base = CommandsGroup("xfer", core, parent)
+		self._cmd_group = CommandsGroup("xfer", core, parent)
 
 	def set_rf(self, data: str) -> None:
 		"""SCPI: XFER:RF \n
