@@ -1,10 +1,10 @@
 """RsSmcv instrument driver
-	:version: 4.80.2.6
+	:version: 4.80.2.11
 	:copyright: 2021 by Rohde & Schwarz GMBH & Co. KG
 	:license: MIT, see LICENSE for more details.
 """
 
-__version__ = '4.80.2.6'
+__version__ = '4.80.2.11'
 
 # Main class
 from RsSmcv.RsSmcv import RsSmcv
@@ -18,6 +18,9 @@ from RsSmcv.Internal.InstrumentErrors import RsInstrException, TimeoutException,
 # Callback Event Argument prototypes
 from RsSmcv.Internal.IoTransferEventArgs import IoTransferEventArgs
 
+# Logging Mode
+from RsSmcv.Internal.ScpiLogger import LoggingMode
+
 # enums
 from RsSmcv import enums
 
