@@ -756,6 +756,13 @@ class CfrFiltMode(Enum):
 	SIMPle = 1
 
 
+# noinspection SpellCheckingInspection
+class ClockModeUnits(Enum):
+	"""2 Members, MSAMple ... SAMPle"""
+	MSAMple = 0
+	SAMPle = 1
+
+
 # noinspection SpellCheckingInspection
 class ClockSourceB(Enum):
 	"""3 Members, AINTernal ... INTernal"""
@@ -764,13 +771,6 @@ class ClockSourceB(Enum):
 	INTernal = 2
 
 
-# noinspection SpellCheckingInspection
-class ClocModeB(Enum):
-	"""2 Members, MSAMple ... SAMPle"""
-	MSAMple = 0
-	SAMPle = 1
-
-
 # noinspection SpellCheckingInspection
 class ClocOutpMode(Enum):
 	"""2 Members, BIT ... SYMBol"""
